function [mfccFilters,centerFreqs]=mel_filterbank(p,N)
% Inputs:	p   number of filters in filterbank
%		N   length of fft
%       min freq is DC, max freq is nyquist
%
% Outputs:	mfccFilters - sparse matrix containing the filterbank amplitudes
%           centerFreqs - the filterbank centre frequencies

global Fs;

fftFreqs = (0:N-1)/N*Fs;  %frequency values
mfccFilters = zeros(p,N); %filterbank amplitudes

delta_mel=1127*log(1+ Fs/2/700)/(p+1); % costant filter spacing in mel 
                                       % =[0,Nyquist] interval/(n. of filters+1) 
filterFreqs=700*(exp([0:delta_mel:(p+1)*delta_mel]/1127)-1); %filter freqs: ...
lowerFreqs = filterFreqs(1:p);                 %lower, ...
centerFreqs = filterFreqs(2:p+1);              %center, ...
upperFreqs = filterFreqs(3:p+2);               %and upper freqs. for each filter

% Assume triangular shaped filters, lower/upper filters taper down to zero
% Each filter has unit max amplitude
for ifilter=1:p
  mfccFilters(ifilter,:) = ...
  (fftFreqs > lowerFreqs(ifilter) & fftFreqs <= centerFreqs(ifilter)).* ...
  (fftFreqs-lowerFreqs(ifilter))/(centerFreqs(ifilter)-lowerFreqs(ifilter)) + ...
  (fftFreqs > centerFreqs(ifilter) & fftFreqs < upperFreqs(ifilter)).* ...
  (upperFreqs(ifilter)-fftFreqs)/(upperFreqs(ifilter)-centerFreqs(ifilter));
end

   plot(fftFreqs,mfccFilters','b');
    %set(gca,'xlim',[fe(1) fe(end)]/1000);
    xlabel('Frequency (kHz)');

