function FMatrix=mfcc_compute(s,Nframe,FrameStep,Nmfcc,p)
%where Nmfcc is the required number of MFCC coefficients. 

%%%TODO: use same notation than ch.2 : hopsize, frame, ...


global Fs;

%Tf=0.025;           %Frame duration in seconds
%N=Fs*Tf;            %Number of samples per frame
%N= 512;
%p=24;              %Number of mel filters
%Ts=0.01;            %Frame step in seconds
%FrameStep=Fs*Ts;    %Frame step in samples

slength=length(s);        %total number of samples in speech


[mfccFilters,centerFreqs]=mel_filterbank(p,Nframe);    %creates mel filter bank

noFrames=floor( (slength-Nframe)/FrameStep ); %Maximum no of frames in speech sample

FMatrix=zeros(noFrames-2, Nmfcc); %Matrix to hold cepstral coefficients
%lifter=1:Nmfcc;                   %Lifter vector index
%lifter=1+floor((Nmfcc)/2)*(sin(lifter*pi/Nmfcc));%raised sine lifter version


%if mean(abs(s)) > 0.01
%    s=s/max(s);                     %Normalises to compensate for mic vol differences
%end

%s = filter([1 -.97], 1, s); %high pass pre-emphasis filter

halfn=1+floor(Nframe/2);    


% Ok, now let's do the processing.  For each chunk of data:
%    * Window the data with a hamming window,
%    * Find the magnitude of the fft,
%    * Convert the fft data into filter bank outputs,
%    * Find the log base 10,
%    * Find the cosine transform to reduce dimensionality.


%Segment the signal into overlapping frames and compute MFCC coefficients
for i=1:noFrames
i
    frame=s((i-1)*FrameStep+1:(i-1)*FrameStep+Nframe);  %Holds individual frames
    F=frame.*hamming(Nframe)';       %multiplies each frame with hamming window
    Ce=log(max(sum(F.^2),2e-22)); %log frame energy, floored
    spectrum=fft(F,Nframe);              %computes the fft

    melspectrum=log10(mfccFilters(:,1:halfn)*( abs(spectrum(1:halfn)).^2 )' );%result is mel-scale filtered
    melspectrum=max(melspectrum,1e-22);
    c=dct(melspectrum);              %obtains DCT, changes to cepstral domain
    %c(1)=Ce;                    %replaces first coefficient
    coeffs=c(1:Nmfcc);            %retains first Nmfcc coefficients
    %ncoeffs=coeffs.*lifter';    %Multiplies coefficients by lifter value
    FMatrix(i, :)=coeffs';     %assigns mfcc coeffs to succesive rows i
end

